Class: SilaRuby::Banks
- Inherits:
-
Object
- Object
- SilaRuby::Banks
- Includes:
- ApiHelpers
- Defined in:
- lib/sila-ruby/banks.rb
Overview
==============================================
BANKS ========================================
Class Method Summary collapse
-
.get_accounts(handle, user_key) ⇒ Object
-------------------------------------------- GET-ACCOUNTS ------------------------------- -------------------------------------------- Gets basic bank account names linked to user handle.
-
.link_account(handle, params = {}, user_key) ⇒ Object
-------------------------------------------- LINK-ACCOUNT ------------------------------- -------------------------------------------- Uses a provided Plaid public token to link a bank account to a verified entity.
-
.plaid_sameday_auth(handle, params = {}, user_key) ⇒ Object
-------------------------------------------- PLAID-SAMEDAY-AUTH ------------------------- --------------------------------------------.
Methods included from ApiHelpers
Class Method Details
.get_accounts(handle, user_key) ⇒ Object
GET-ACCOUNTS -------------------------------
Gets basic bank account names linked to user handle
39 40 41 42 43 |
# File 'lib/sila-ruby/banks.rb', line 39 def self.get_accounts(handle, user_key) header = { user_handle: handle } = 'get_accounts_msg' sila_post_signed('get_accounts', header, , nil, user_key) end |
.link_account(handle, params = {}, user_key) ⇒ Object
LINK-ACCOUNT -------------------------------
Uses a provided Plaid public token to link a bank account to a verified entity
20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/sila-ruby/banks.rb', line 20 def self.link_account(handle, params={}, user_key) header = { user_handle: handle } = 'link_account_msg' # Example of params passed # # params = { # public_token: "public-xxx-xxx", # account_name: "Custom Account Name", # selected_account_id: "optional_selected_account_id" # } sila_post_signed('link_account', header, , params, user_key) end |
.plaid_sameday_auth(handle, params = {}, user_key) ⇒ Object
PLAID-SAMEDAY-AUTH -------------------------
48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/sila-ruby/banks.rb', line 48 def self.plaid_sameday_auth(handle, params={}, user_key) header = { user_handle: handle } = 'header_msg' # Example of params passed # # params = { # account_name: "Custom Account Name", # } sila_post_signed('plaid_sameday_auth', header, , params, user_key) end |